/*!
 * vue-coe-feedback v0.0.6
 * (c) 2018-present Vinicius Azevedo <viniazvd@gmail.com>
 * Released under the MIT License.
 */
var feedbackFactory = function (context) {
  return {
    // getter
    list: context.$store.getters.__feedbacks,

    // actions
    delay: function delay(delay$1) {
      context.$store.dispatch('FEEDBACK_DELAY', delay$1);
    },

    add: function add(feedbacks) {
      context.$store.dispatch('FEEDBACKS_ADD', feedbacks);
    },

    remove: function remove(feedback) {
      context.$store.dispatch('FEEDBACK_REMOVE', feedback);
    }

  };
};

var feedbackStore = {
  state: {
    feedbacks: [],
    delay: 0
  },
  getters: {
    __feedbacks: function (ref) {
      var feedbacks = ref.feedbacks;

      return feedbacks;
},
    __delay: function (ref) {
      var delay = ref.delay;

      return delay;
}
  },
  mutations: {
    SET_FEEDBACKS: function (state, feedbacks) { return state.feedbacks = feedbacks; },
    SET_DELAY: function (state, delay) { return state.delay = delay; }
  },
  actions: {
    FEEDBACK_DELAY: function (ref, delay) {
      var commit = ref.commit;

      commit('SET_DELAY', delay);
    },
    FEEDBACKS_ADD: function (ref, payload) {
      var commit = ref.commit;
      var getters = ref.getters;
      var dispatch = ref.dispatch;

      var isError = payload instanceof Error;
      var feedback = {
        type: payload.type || isError && 'error',
        message: payload.message,
        highlighted: payload.highlighted
      };
      commit('SET_FEEDBACKS', getters['__feedbacks'].concat( [feedback]));
      setTimeout(function () {
        dispatch('FEEDBACK_REMOVE', feedback);
      }, getters['__delay']);
    },
    FEEDBACK_REMOVE: function (ref, payload) {
      var commit = ref.commit;
      var getters = ref.getters;

      var feedbacks = getters['__feedbacks'].filter(function (feedback) { return feedback !== payload; });
      commit('SET_FEEDBACKS', feedbacks);
    }
  }
};

var registerStore = function (store, storeName) {
  store.registerModule(storeName, Object.assign({}, feedbackStore));
};

var index = {
  install: function install(Vue, store, options) {
    if ( options === void 0 ) options = {};

    if (!store) {
      console.error('stack need store');
      return false;
    }

    var storeName = options.storeName;
    var delay = options.delay;
    if (!storeName) { storeName = 'coefeedback'; }
    if (!delay) { delay = 5000; }
    registerStore(store, storeName, delay);
    store.dispatch('FEEDBACK_DELAY', delay);
    Object.defineProperty(Vue.prototype, '$feedback', {
      get: function get() {
        return feedbackFactory(this);
      }

    });
  }

};

var colorValidator = function (color) {
  var rule = /(^#+([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$)/i;
  return color.match(rule);
};

//
var script = {
  props: {
    feedbacks: {
      type: Array,
      default: function () { return []; }
    },
    info: {
      type: String,
      default: '#b4b4b4',
      validator: function (color) { return colorValidator(color); }
    },
    success: {
      type: String,
      default: '#59efb2',
      validator: function (color) { return colorValidator(color); }
    },
    error: {
      type: String,
      default: '#ef5959',
      validator: function (color) { return colorValidator(color); }
    }
  },
  computed: {
    color: function color() {
      return {
        '--info': this.info,
        '--success': this.success,
        '--error': this.error
      };
    }

  },

  install: function install(Vue) {
    Vue.component('CoeFeedback', this);
  }

};

/* script */
            var __vue_script__ = script;
/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "transition-group",
    { staticClass: "coe-feedbacks", attrs: { name: "feedback", tag: "ul" } },
    [
      _vm._t(
        "feedbacks",
        _vm._l(_vm.feedbacks, function(feedback, index) {
          return _c(
            "li",
            {
              key: index,
              class: ["feedback", "-" + feedback.type],
              style: _vm.color
            },
            [
              _vm._t("message", [
                _c("div", { staticClass: "message-container" }, [
                  _c("span", { staticClass: "message" }, [
                    _vm._v(_vm._s(feedback.message) + " ")
                  ]),
                  _vm._v(" "),
                  _c("span", { staticClass: "highlighted" }, [
                    _vm._v(_vm._s(feedback.highlighted))
                  ])
                ])
              ]),
              _vm._v(" "),
              _vm._t("button", [
                _c(
                  "div",
                  {
                    staticClass: "button",
                    on: {
                      click: function($event) {
                        _vm.$emit("close", feedback);
                      }
                    }
                  },
                  [_c("div", { staticClass: "icon" }, [_vm._v("×")])]
                )
              ])
            ],
            2
          )
        }),
        {
          feedbacks: _vm.feedbacks,
          info: _vm.info,
          success: _vm.success,
          error: _vm.error
        }
      )
    ],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  var __vue_inject_styles__ = undefined;
  /* scoped */
  var __vue_scope_id__ = undefined;
  /* module identifier */
  var __vue_module_identifier__ = undefined;
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* component normalizer */
  function __vue_normalize__(
    template, style, script$$1,
    scope, functional, moduleIdentifier,
    createInjector, createInjectorSSR
  ) {
    var component = (typeof script$$1 === 'function' ? script$$1.options : script$$1) || {};

    // For security concerns, we use only base name in production mode.
    component.__file = "/Users/convenia/Desktop/convenia-spa/vue-coe-feedback/src/components/CoeFeedback.vue";

    if (!component.render) {
      component.render = template.render;
      component.staticRenderFns = template.staticRenderFns;
      component._compiled = true;

      if (functional) { component.functional = true; }
    }

    component._scopeId = scope;

    

    return component
  }
  /* style inject */
  
  /* style inject SSR */
  

  
  var CoeFeedback = __vue_normalize__(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    undefined,
    undefined
  )

export { index as VueCoeFeedback, CoeFeedback };
